@@ -14,8 +14,8 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <mousepad/mousepad-private.h>
-#include <mousepad/mousepad-application.h>
+#include "mousepad-private.h"
+#include "mousepad-application.h"
 
 #ifdef HAVE_LIBINTL_H
 #include <libintl.h>
@@ -28,10 +28,11 @@
 
 
 gint
-main (gint argc, gchar **argv)
+main (gint argc,
+      gchar **argv)
 {
   MousepadApplication *application;
-  gint                 status;
+  gint status;
 
   /* bind the text domain to the locale directory */
   setlocale (LC_ALL, "");
@@ -43,16 +44,10 @@ main (gint argc, gchar **argv)
   /* set the package textdomain */
   textdomain (GETTEXT_PACKAGE);
 
-#ifdef G_ENABLE_DEBUG
-  /* crash when something went wrong */
-  g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
-#endif
-
   /* create the application */
   application = g_object_new (MOUSEPAD_TYPE_APPLICATION,
                               "application-id", MOUSEPAD_ID,
-                              "flags", G_APPLICATION_HANDLES_COMMAND_LINE
-                                       | G_APPLICATION_HANDLES_OPEN,
+                              "flags", G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_HANDLES_OPEN,
                               NULL);
 
   /* run the application */
